@@ -2,7 +2,7 @@
 # ==============================================================================
 # portsreinstall library script
 # - Operations of commands as well as check of command line arguments -
-# Copyright (C) 2013-2015 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
+# Copyright (C) 2013-2016 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
 # This software is distributed under the 2-Clause BSD License.
 # ==============================================================================
 
@@ -101,7 +101,7 @@ command_parse_args ()
 	ok|taboo|need|noneed)
 		misc_chk_privilege
 		[ $COMMAND_MODE = ok ] && database_query_chk_preparation_completion
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		COMMAND_OPERATION=$1
 		shift || :
 		case $COMMAND_OPERATION in
@@ -121,7 +121,7 @@ command_parse_args ()
 	reselect)
 		misc_chk_privilege
 		database_query_chk_preparation_completion
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		COMMAND_OPERATION=$1
 		shift || :
 		case $COMMAND_OPERATION in
@@ -200,16 +200,16 @@ command_parse_args ()
 		;;
 	reconf|rmconf|forget|escape|restore)
 		misc_chk_privilege
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		_command_parse_args__chk_glob_args $#
 		;;
 	pkgsanity)
 		misc_chk_privilege
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		;;
 	show)
 		database_query_chk_preparation_completion
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		if ! expr "$1" : '@.*' > /dev/null
 		then
 			COMMAND_SHOW_SUBJECT=${1:-todo}
@@ -255,7 +255,7 @@ command_parse_args ()
 		COMMAND_DO_MODE=$COMMAND_MODE
 		COMMAND_MODE=do
 		misc_chk_privilege
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		_command_parse_args__chk_no_arg $#
 		;;
 	redo|do)
@@ -269,7 +269,7 @@ command_parse_args ()
 			;;
 		esac
 		misc_chk_privilege
-		temp_warn_obsolete_temp_db
+		temp_warn_obsolete_temp_db >&2
 		_command_parse_args__chk_no_arg $#
 		if [ "$COMMAND_DO_MODE" = prepare ]
 		then
