@@ -2,7 +2,7 @@
 # ==============================================================================
 # portsreinstall library script
 # - Wrappers for hiding version differences in the Ports/Packages system -
-# Copyright (C) 2013-2015 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
+# Copyright (C) 2013-2016 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
 # This software is distributed under the 2-Clause BSD License.
 # ==============================================================================
 
@@ -91,6 +91,12 @@ pkgsys_is_necessary_pkgtool ()
 	[ x"$WITH_PKGNG" = x'yes' -a \( x"$1" = x'ports-mgmt/pkg' -o x"$1" = x'ports-mgmt/pkg-devel' \) ]
 }
 
+# ============= Get the extended regular expression pattern of ports for pkg(8) =============
+pkgsys_pkgtools_ports_filter_regexp ()
+{
+	echo '^ports-mgmt/(pkg|pkg-devel)$'
+}
+
 # ============= Check whether the dialog for selecting port options is dialog4ports =============
 pkgsys_is_dialog4ports_used ()
 {
@@ -419,6 +425,7 @@ pkgsys_def_pkgtools ()
 				message_echo "INFO: $pkg is successfully registered."
 			else
 				message_echo "WARNING: Failed to register $pkg, but the process is continued." >&2
+				return 1
 			fi
 		}
 		pkg_add_f ()
