@@ -2,7 +2,7 @@
 # ==============================================================================
 # portsreinstall library script
 # - Reinstallation processes -
-# Copyright (C) 2013-2015 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
+# Copyright (C) 2013-2016 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
 # This software is distributed under the 2-Clause BSD License.
 # ==============================================================================
 
@@ -337,7 +337,7 @@ reinstall_restore_conflicts ()
 	done < $tmpsrc
 }
 
-# ============= Check whether the all requirements are installed =============
+# ============= Check whether the all non-looped requirements are installed =============
 reinstall_are_requirements_ready ()
 {
 	[ -e "$REINSTALL_DBNODE_DIR/requirements.all.direct" ] || return 0
@@ -347,7 +347,7 @@ reinstall_are_requirements_ready ()
 	done < $REINSTALL_DBNODE_DIR/requirements.all.direct
 }
 
-# ============= Get the all requirements ready for a port by restarting them if deinstalled =============
+# ============= Get the all non-looped requirements ready for a port by restarting them if deinstalled =============
 reinstall_chk_and_restore_requirements ()
 {
 	local tmp_restore tmp_isfailed
@@ -512,7 +512,10 @@ reinstall_tell_update_to_depandents ()
 		for level in full direct
 		do
 			dbsuffix=${tag}.${level}
-			cat "$REINSTALL_DBNODE_DIR/dependents.$dbsuffix" "$REINSTALL_DBNODE_DIR/dependents.$dbsuffix.orig" 2> /dev/null \
+			{
+				cat "$REINSTALL_DBNODE_DIR/dependents.$dbsuffix" "$REINSTALL_DBNODE_DIR/dependents.$dbsuffix.orig"
+				[ -e "$REINSTALL_DBNODE_DIR/succeeded_once" ] || cat "$REINSTALL_DBNODE_DIR/ignored_dependents.$tag" "$REINSTALL_DBNODE_DIR/ignored_dependents.$tag.orig"
+			} 2> /dev/null \
 				| sort -u \
 				| while read origin_dependent
 			do
